@@ -6,6 +6,8 @@
 #ifdef Q_WS_MAEMO5
 #include <QtMaemo5/QMaemo5InformationBox>
 #endif
+#define NORMAL "normal"
+#define REMOVE "remove"
 
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindow)
@@ -35,6 +37,7 @@ MainWindow::MainWindow(QWidget *parent)
     connect(articleList, SIGNAL(articleToPlaylist(QString,QString)), this, SLOT(addToPlaylist(QString,QString)));
     connect(network, SIGNAL(playlistArticleSaved()), message, SLOT(hide()));
     connect(player, SIGNAL(openArticleFromLink(QListWidgetItem*)), this, SLOT(openArticleFromLink(QListWidgetItem*)));
+    connect(options, SIGNAL(removePlaylistsButtonClicked()), this, SLOT(removePlaylistsMode()));
    // connect(network, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(updateProgressBar(qint64,qint64)));
 }
 
@@ -266,3 +269,38 @@ void MainWindow::addToPlaylist(QString playlistname, QString item)
 
 
 }*/
+
+void MainWindow::on_searchLineEdit_textChanged(const QString &arg1)
+{
+
+}
+
+void MainWindow::on_searchLineEdit_returnPressed()
+{
+    if (this->ui->searchLineEdit->text().isEmpty())
+    {
+        #ifdef Q_WS_MAEMO5
+        QMaemo5InformationBox::information(this, "Please enter search word first",
+                                                    QMaemo5InformationBox::DefaultTimeout);
+        #endif
+    }
+    else
+    {
+        message->setLabelText("Searching");
+        message->show();
+        network->searchKeyWord(this->ui->searchLineEdit->text());
+        this->searchWord = this->ui->searchLineEdit->text();
+    }
+}
+
+void MainWindow::removePlaylistsMode()
+{
+    if (articleList->isVisible())
+            articleList->hide();
+    else if (player->isVisible())
+        player->hide();
+
+    this->playlist->show();
+    this->playlist->setMode(REMOVE);
+
+}
